@@ -37,7 +37,7 @@ static const unsigned int TICKS_PER_SECOND = 1000 / GAME_TIME_DELAY;
 static const unsigned int OVERLAY_Z_VALUE = 1000;
 
 BomberGameWidget::BomberGameWidget(KgThemeProvider *provider, QWidget *parent) :
-    QGraphicsView(parent), m_state(BeforeFirstGame), m_level(0), m_lives(0), m_time(0),
+    QGraphicsView(parent), m_state(State::BeforeFirstGame), m_level(0), m_lives(0), m_time(0),
     m_renderer(provider)
 {
     // Gameboard
@@ -69,7 +69,6 @@ BomberGameWidget::BomberGameWidget(KgThemeProvider *provider, QWidget *parent) :
 BomberGameWidget::~BomberGameWidget()
 {
     delete m_board;
-    //delete m_overlay; // m_overlay is implicitly deleted by m_board
 }
 
 unsigned int BomberGameWidget::level() const
@@ -84,10 +83,10 @@ unsigned int BomberGameWidget::score() const
 
 void BomberGameWidget::closeGame()
 {
-    if (m_state != BeforeFirstGame && m_state != GameOver) {
+    if (m_state != State::BeforeFirstGame && m_state != State::GameOver) {
         closeLevel();
 
-        m_state = GameOver;
+        m_state = State::GameOver;
         emit stateChanged(m_state);
         emit gameOver();
 
@@ -113,35 +112,31 @@ void BomberGameWidget::newGame()
 
 void BomberGameWidget::setPaused(bool val)
 {
-    if (m_state == Paused && val == false) {
+    if (m_state == State::Paused && val == false) {
         m_clock->start();
         m_board->setPaused(false);
-        m_state = Running;
-        emit stateChanged(m_state);
-    } else if (m_state == Running && val == true) {
+        m_state = State::Running;
+    } else if (m_state == State::Running && val == true) {
         m_clock->stop();
         m_board->setPaused(true);
-        m_state = Paused;
-        emit stateChanged(m_state);
+        m_state = State::Paused;
     }
-
+    emit stateChanged(m_state);
     redraw();
 }
 
 void BomberGameWidget::setSuspended(bool val)
 {
-    if (m_state == Suspended && val == false) {
+    if (m_state == State::Suspended && val == false) {
         m_clock->start();
         m_board->setPaused(false);
-        m_state = Running;
-        emit stateChanged(m_state);
-    }
-    if (m_state == Running && val == true) {
+        m_state = State::Running;
+    } else if (m_state == State::Running && val == true) {
         m_clock->stop();
         m_board->setPaused(true);
-        m_state = Suspended;
-        emit stateChanged(m_state);
+        m_state = State::Suspended;
     }
+    emit stateChanged(m_state);
     redraw();
 }
 
@@ -157,7 +152,7 @@ void BomberGameWidget::setSounds(bool val)
 
 void BomberGameWidget::onPlaneCrashed()
 {
-    m_lives--;
+    --m_lives;
     emit livesChanged(m_lives);
     if (m_lives <= 0) {
         closeGame();
@@ -169,24 +164,23 @@ void BomberGameWidget::onPlaneCrashed()
 void BomberGameWidget::onBombHit()
 {
     unsigned int bonus = SCORE_INCREMENT * m_level;
-    m_score += bonus; emit
-    scoreChanged(m_score);
+    m_score += bonus;
+    emit scoreChanged(m_score);
     m_scoreLeftBeforeNewLife -= bonus;
     if (m_scoreLeftBeforeNewLife <= 0) {
         m_scoreLeftBeforeNewLife = NEW_LIVE_AT_SCORE;
-        m_lives++;
+        ++m_lives;
         emit livesChanged(m_lives);
     }
-
 }
 
 void BomberGameWidget::tick()
 {
     static signed int ticks = TICKS_PER_SECOND;
-    ticks--;
+    --ticks;
     if (ticks <= 0) {
-        m_time++; emit
-        timeChanged(m_time);
+        ++m_time;
+        emit timeChanged(m_time);
         ticks = TICKS_PER_SECOND;
     }
 }
@@ -206,16 +200,15 @@ void BomberGameWidget::closeLevel()
 
 void BomberGameWidget::newLevel()
 {
-    m_state = Running; emit
-    stateChanged(m_state);
+    m_state = State::Running;
+    emit stateChanged(m_state);
 
     m_clock->start();
     m_board->newLevel(m_level);
     m_board->setPaused(false);
 
-    emit
-    livesChanged(m_lives); emit
-    timeChanged(m_time);
+    emit livesChanged(m_lives);
+    emit timeChanged(m_time);
 
     redraw();
 }
@@ -229,11 +222,11 @@ void BomberGameWidget::mouseReleaseEvent(QMouseEvent *event)
 
 void BomberGameWidget::onDropBomb()
 {
-    if (m_state == Running) {
+    if (m_state == State::Running) {
         m_board->dropBomb();
-    } else if (m_state == BetweenLevels) {
+    } else if (m_state == State::BetweenLevels) {
         newLevel();
-    } else if (m_state == BeforeFirstGame) {
+    } else if (m_state == State::BeforeFirstGame) {
         newGame();
     }
 }
@@ -245,14 +238,14 @@ void BomberGameWidget::redraw()
     }
     QGraphicsItem *item;
     switch (m_state) {
-    case BeforeFirstGame:
+    case State::BeforeFirstGame:
         foreach (item, m_board->items()) {
             item->hide();
         }
         generateOverlay();
         m_overlay->show();
         break;
-    case Running:
+    case State::Running:
         foreach (item, m_board->items()) {
             item->show();
         }
@@ -286,17 +279,17 @@ void BomberGameWidget::generateOverlay()
 
     QString text;
     switch (m_state) {
-    case BeforeFirstGame:
+    case State::BeforeFirstGame:
         text = i18nc("Message show to the user when the game is loaded", "Welcome to Bomber.\nClick to start a game");
         break;
-    case Paused:
+    case State::Paused:
         text = i18nc("Message show to the user while the game is paused", "Paused");
         break;
-    case BetweenLevels:
+    case State::BetweenLevels:
         text = i18nc("Message telling user which level they just completed", "You have successfully cleared level %1\n", m_level - 1)
                + i18nc("Message telling user which level they are about to start", "On to level %1.", m_level);
         break;
-    case GameOver:
+    case State::GameOver:
         text = i18nc("Used to tell the user that the game is over", "Game over.");
         break;
     default:
@@ -308,8 +301,8 @@ void BomberGameWidget::generateOverlay()
     p.setFont(font);
     unsigned int textWidth = p.boundingRect(p.viewport(), Qt::AlignCenter | Qt::AlignVCenter, text).width();
     unsigned int fontSize = 28;
-    while ((textWidth > itemWidth * 0.95)) {
-        fontSize--;
+    while (textWidth > itemWidth * 0.95) {
+        --fontSize;
         font.setPointSize(fontSize);
         p.setFont(font);
         textWidth = p.boundingRect(p.viewport(), Qt::AlignCenter | Qt::AlignVCenter, text).width();
@@ -326,17 +319,14 @@ void BomberGameWidget::generateOverlay()
 
 void BomberGameWidget::onLevelCleared()
 {
-    if (m_state == Running) {
-        m_state = BetweenLevels;
+    if (m_state == State::Running) {
+        m_state = State::BetweenLevels;
         closeLevel();
-        m_level++; emit
-        levelChanged(m_level);
-
-        emit
-        stateChanged(m_state);
+        ++m_level;
+        emit levelChanged(m_level);
+        emit stateChanged(m_state);
         redraw();
     }
-
 }
 
 BomberGameWidget::State BomberGameWidget::state() const
